@@ -1,11 +1,11 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-2004 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,17 +14,17 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: ArgV.h,v 1.17 2004/02/17 10:44:19 lav Exp $ */
+/* $Id: ArgV.h,v 1.25 2010/12/28 11:46:25 lav Exp $ */
 
 #ifndef ARGV_H
 #define ARGV_H
 
-#include <stdio.h>
+#include "trio.h"
 #include "StringSet.h"
+#include "getopt.h"
 
 class ArgV : public StringSet
 {
@@ -37,19 +37,22 @@ public:
    ArgV(const ArgV& a) : StringSet(a) { ind=0; }
    ArgV(const ArgV *a) : StringSet(*a) { ind=0; }
    ArgV(int new_c,const char * const *new_v) : StringSet(new_v,new_c) { ind=0; }
+   ~ArgV();
 
    void Append(const char *s) { StringSet::Append(s); }
-   void Append(int a) { char buf[12]; sprintf(buf,"%d",a); Append(buf); }
+   void Append(int a) { char buf[32]; sprintf(buf,"%d",a); Append(buf); }
    void Add(const char *a) { Append(a); } // alias
 
-   char *Combine(int start_index=0) const;
+   char *Combine(int start_index=0,int end_index=0) const;
    char *CombineQuoted(int start_index=0) const;
+   char *CombineCmd(int i=0) const;
 
-   int getopt_long(const char *opts,const struct option *lopts,int *lind);
+   int getopt_long(const char *opts,const struct option *lopts,int *lind=0);
    int getopt(const char *opts)
       {
 	 return getopt_long(opts,0,0);
       }
+   const char *getopt_error_message(int e);
 
    void seek(int n);
    void rewind() { seek(0); }
