@@ -1,11 +1,11 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-1997 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef CHARREADER_H
@@ -23,6 +22,7 @@
 
 #include "SMTask.h"
 
+// CharReader fetches a single character from given file descriptor.
 class CharReader : public SMTask
 {
    int	 fd;
@@ -31,8 +31,7 @@ class CharReader : public SMTask
    int	 Do();
 
 public:
-   static const int NOCHAR=-2;
-   static const int EOFCHAR=-1;
+   enum { NOCHAR=-2, EOFCHAR=-1 };
 
    int	 GetChar() { return ch; };
 
