@@ -1,11 +1,11 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-1997 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,18 +14,17 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: Filter.h,v 1.23.2.1 2007/04/05 13:23:38 lav Exp $ */
+/* $Id: Filter.h,v 1.27 2008/11/27 05:56:15 lav Exp $ */
 
 #ifndef FILTER_H
 #define FILTER_H
 
 #include "ProcWait.h"
+#include "ArgV.h"
 
-class ArgV;
 class FileTimestamp;
 
 class FDStream
@@ -34,10 +33,10 @@ class FDStream
 
 public:
    int fd;
-   char *name;
-   char *full_name;
-   char *cwd;
-   char *error_text;
+   xstring_c name;
+   xstring_c full_name;
+   xstring_c cwd;
+   xstring error_text;
    const char *status;
 
    bool	 error() { return error_text!=0; }
@@ -72,11 +71,13 @@ public:
 
 class OutputFilter : public FDStream
 {
-   ArgV *a;
+   Ref<ArgV> a;
    ProcWait *w;
    pid_t pg;
-   FDStream *second;
-   bool delete_second;
+
+   Ref<FDStream> my_second;
+   const Ref<FDStream>& second;
+
    bool stderr_to_stdout;
    bool stdout_to_null;
 
@@ -93,8 +94,10 @@ protected:
 public:
    OutputFilter(const char *filter,int second_fd=-1);
    OutputFilter(const char *filter,FDStream *second);
+   OutputFilter(const char *filter,const Ref<FDStream>& second);
    OutputFilter(ArgV *a,int second_fd=-1);
    OutputFilter(ArgV *a,FDStream *second);
+   OutputFilter(ArgV *a,const Ref<FDStream>& second);
    virtual ~OutputFilter();
 
    void StderrToStdout() { stderr_to_stdout=true; }
@@ -111,8 +114,6 @@ public:
    int GetProcExitCode() { return w->GetInfo()>>8; }
 
    bool broken();
-
-   void DeleteSecondaryStream() { delete_second=true; }
 };
 
 class InputFilter : public OutputFilter
