@@ -1,11 +1,11 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1999-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: FtpDirList.cc,v 1.30 2007/08/13 18:58:26 lav Exp $ */
+/* $Id: FtpDirList.cc,v 1.32 2011/03/25 14:35:42 lav Exp $ */
 
 #include <config.h>
 
@@ -121,12 +120,10 @@ int FtpDirList::Do()
 
 const char *FtpDirList::Status()
 {
-   static char s[256];
    if(ubuf && !ubuf->Eof() && session->IsOpen())
    {
-      sprintf(s,_("Getting file list (%lld) [%s]"),
+      return xstring::format(_("Getting file list (%lld) [%s]"),
 		     (long long)session->GetPos(),session->CurrentStatus());
-      return s;
    }
    return "";
 }
@@ -149,7 +146,7 @@ void FtpDirList::FormatGeneric(FileInfo *fi)
       fi->mode=(dir?0755:0644);
    char size_str[32];
    if(fi->defined&fi->SIZE)
-      sprintf(size_str,"%lld",(long long)fi->size);
+      snprintf(size_str,sizeof(size_str),"%lld",(long long)fi->size);
    else
       strcpy(size_str,"-");
    const char *date_str="-";
