@@ -1,11 +1,11 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1999 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,20 +14,18 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: FtpDirList.h,v 1.8 2004/03/24 22:27:30 lav Exp $ */
+/* $Id: FtpDirList.h,v 1.12 2008/11/27 05:56:17 lav Exp $ */
 
 #ifndef FTPDIRLIST_H
 #define FTPDIRLIST_H
 
 class FtpDirList : public DirList
 {
-   FileAccess *session;
-   IOBuffer *ubuf;
-   char *pattern;
+   SMTaskRef<IOBuffer> ubuf;
+   xstring_ca pattern;
 
    bool TryEPLF(const char *line,int len);
    bool TryMLSD(const char *line,int len);
@@ -36,13 +34,13 @@ class FtpDirList : public DirList
    void FormatGeneric(class FileInfo *);
 
 public:
-   FtpDirList(ArgV *a,FileAccess *fa);
-   ~FtpDirList();
+   FtpDirList(FileAccess *s,ArgV *a)
+      : DirList(s,a), pattern(args->Combine(1)) {}
    const char *Status();
    int Do();
 
-   void Suspend();
-   void Resume();
+   void SuspendInternal();
+   void ResumeInternal();
 };
 
 #endif//FTPDIRLIST_H
