@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1998-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: FtpListInfo.cc,v 1.65 2009/09/15 07:56:29 lav Exp $ */
+/* $Id: FtpListInfo.cc,v 1.66 2011/06/28 09:45:56 lav Exp $ */
 
 #include <config.h>
 #include "FtpListInfo.h"
@@ -495,7 +494,7 @@ FileInfo *ParseFtpLongList_EPLF(char *line,int *err,const char *)
    if(name==0 || !type_known)
       ERR;
 
-   fi=new FileInfo(name);
+   fi=new FileInfo(xstring::get_tmp(name,name_len));
    if(size!=NO_SIZE)
       fi->SetSize(size);
    if(date!=NO_DATE)
