@@ -1,11 +1,11 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 2001-2002 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* Get information about a path (dir or file).  If _dir is a file, get
@@ -104,10 +103,15 @@ GetFileInfo::GetFileInfo(const FileAccessRef& a, const char *_dir, bool _showdir
    }
 }
 
-GetFileInfo::~GetFileInfo()
+GetFileInfo::~GetFileInfo() {}
+
+void GetFileInfo::PrepareToDie()
 {
-   session->Close();
-   session->SetCwd(origdir);
+   if(session)
+   {
+      session->Close();
+      session->SetCwd(origdir);
+   }
 }
 
 int GetFileInfo::Do()
