@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-2000 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: GetJob.cc,v 1.33 2010/01/21 08:22:26 lav Exp $ */
+/* $Id: GetJob.cc,v 1.36 2010/05/24 13:00:22 lav Exp $ */
 
 #include <config.h>
 #include <sys/types.h>
@@ -34,7 +33,7 @@
 #include "ArgV.h"
 #include "url.h"
 
-ResDecl res_clobber	("xfer:clobber",     "yes",ResMgr::BoolValidate,ResMgr::NoClosure);
+ResDecl res_clobber	("xfer:clobber",     "no", ResMgr::BoolValidate,ResMgr::NoClosure);
 ResDecl res_make_backup	("xfer:make-backup", "yes",ResMgr::BoolValidate,ResMgr::NoClosure);
 
 #define super CopyJobEnv
@@ -64,7 +63,7 @@ FileCopyPeer *GetJob::SrcLocal(const char *src)
 }
 FileCopyPeer *GetJob::DstLocal(const char *dst)
 {
-   bool clobber=res_clobber.QueryBool(0);
+   bool clobber=(cont || res_clobber.QueryBool(0));
    int flags=O_WRONLY|O_CREAT|(truncate_target_first?O_TRUNC:0)|(clobber?0:O_EXCL);
    dst=expand_home_relative(dst);
    const char *f=(cwd && dst[0]!='/') ? dir_file(cwd,dst) : dst;
