@@ -1,11 +1,11 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-1997 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -24,22 +23,14 @@
 #include <unistd.h>
 #include <termios.h>
 
-#include "xmalloc.h"
 #include "GetPass.h"
 #include "CharReader.h"
 #include "SignalHook.h"
 
-char *GetPass(const char *prompt)
+const char *GetPass(const char *prompt)
 {
-   static char *oldpass=0;
+   static xstring_c oldpass;
    static int tty_fd=-2;
-   static FILE *f=0;
-
-   if(oldpass)
-   {
-      free(oldpass);
-      oldpass=0;
-   }
 
    if(tty_fd==-2)
    {
@@ -55,21 +46,15 @@ char *GetPass(const char *prompt)
    if(tty_fd==-1)
       return 0;
 
-   if(f==0)
-      f=fdopen(tty_fd,"r");
-   if(f==0)
-      return 0;
-
    write(tty_fd,prompt,strlen(prompt));
 
-
    struct termios tc;
    tcgetattr(tty_fd,&tc);
    tcflag_t old_lflag=tc.c_lflag;
    tc.c_lflag&=~ECHO;
    tcsetattr(tty_fd,TCSANOW,&tc);
 
-   oldpass=readline_from_file(f);
+   oldpass.set_allocated(readline_from_file(tty_fd));
 
    tc.c_lflag=old_lflag;
    tcsetattr(tty_fd,TCSANOW,&tc);
@@ -79,16 +64,12 @@ char *GetPass(const char *prompt)
    return oldpass;
 }
 
-char *readline_from_file(FILE *f)
+char *readline_from_file(int fd)
 {
-   int	 size=0x800;
-   char	 *line=(char*)xmalloc(size);
-   int	 len=0;
-   char  *ptr=line;
-
+   xstring line("");
    for(;;)
    {
-      CharReader r(fileno(f));
+      CharReader r(fd);
       int c;
       for(;;)
       {
@@ -98,28 +79,12 @@ char *readline_from_file(FILE *f)
 	    break;
 	 SMTask::Block();
 	 if(SignalHook::GetCount(SIGINT)>0)
-	 {
-	    free(line);
-	    return(NULL);
-	 }
+	    return(xstrdup(""));
       }
-      if(c==r.EOFCHAR && ptr==line)
-      {
-	 free(line);
+      if(c==r.EOFCHAR && line.length()==0)
 	 return(NULL);
-      }
       if(c==r.EOFCHAR || c=='\n')
-      {
-	 *ptr=0;
-	 return(line);
-      }
-      if(len+2>=size)
-      {
-	 size*=2;
-	 line=(char*)xrealloc(line,size);
-	 ptr=line+len;
-      }
-      *ptr++=c;
-      len++;
+	 return(line.borrow());
+      line.append(c);
    }
 }
