@@ -1,11 +1,11 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1999 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: HttpDir.h,v 1.18 2005/03/29 08:24:55 lav Exp $ */
+/* $Id: HttpDir.h,v 1.22 2008/11/27 05:56:19 lav Exp $ */
 
 #ifndef HTTPDIR_H
 #define HTTPDIR_H
@@ -44,14 +43,13 @@ class ParsedURL;
 
 class HttpDirList : public DirList
 {
-   FileAccess *session;
-   IOBuffer *ubuf;
+   Ref<IOBuffer> ubuf;
    const char *curr;
-   ParsedURL *curr_url;
+   Ref<ParsedURL> curr_url;
    FileSet all_links;
    int mode;
    bool parse_as_html;
-   char *base_href;
+   xstring_c base_href;
 
 #if USE_EXPAT
    XML_Parser xml_p;
@@ -63,13 +61,13 @@ class HttpDirList : public DirList
    void ParsePropsFormat(const char *b,int len,bool eof);
 
 public:
-   HttpDirList(ArgV *a,FileAccess *fa);
+   HttpDirList(FileAccess *s,ArgV *a);
    ~HttpDirList();
    const char *Status();
    int Do();
 
-   void Suspend();
-   void Resume();
+   void SuspendInternal();
+   void ResumeInternal();
 };
 
 #endif//HTTPDIR_H
