@@ -1,11 +1,11 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-2002 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: LocalAccess.cc,v 1.62 2008/05/22 13:20:36 lav Exp $ */
+/* $Id: LocalAccess.cc,v 1.69 2011/03/25 14:35:42 lav Exp $ */
 
 #include <config.h>
 #include <errno.h>
@@ -63,6 +62,7 @@ LocalAccess::LocalAccess() : FileAccess()
    Init();
    xstring_ca c(xgetcwd());
    cwd.Set(c?c.get():".");
+   LogNote(10,"local cwd is `%s'",cwd.path.get());
 }
 LocalAccess::LocalAccess(const LocalAccess *o) : FileAccess(o)
 {
@@ -71,13 +71,13 @@ LocalAccess::LocalAccess(const LocalAccess *o) : FileAccess(o)
 
 void LocalAccess::errno_handle()
 {
-   int e=errno;
-   const char *err=strerror(e);
+   saved_errno=errno;
+   const char *err=strerror(saved_errno);
    if(mode==RENAME)
       error.vset("rename(",file.get(),", ",file1.get(),"): ",err,NULL);
    else
       error.vset(file.get(),": ",err,NULL);
-   if(e!=EEXIST)
+   if(saved_errno!=EEXIST)
       LogError(0,"%s",error.get());
 }
 
@@ -113,24 +113,24 @@ int LocalAccess::Do()
    case(QUOTE_CMD):
       if(stream==0)
       {
-	 char *cmd=(char*)alloca(10+xstrlen(file));
+	 const char *cmd=0;
 	 // FIXME: shell-quote file name
 	 if(mode==LIST)
 	 {
 	    if(file && file[0])
-	       sprintf(cmd,"ls %s",file.get());
+	       cmd=xstring::cat("ls ",shell_encode(file),NULL);
 	    else
-	       strcpy(cmd,"ls");
+	       cmd="ls";
 	 }
 	 else if(mode==LONG_LIST)
 	 {
 	    if(file && file[0])
-	       sprintf(cmd,"ls -l %s",file.get());
+	       cmd=xstring::cat("ls -l",shell_encode(file),NULL);
 	    else
-	       strcpy(cmd,"ls -la");
+	       cmd="ls -la";
 	 }
 	 else// if(mode==QUOTE_CMD)
-	    strcpy(cmd,file);
+	    cmd=file;
 	 LogNote(5,"running `%s'",cmd);
 	 InputFilter *f_stream=new InputFilter(cmd);
 	 f_stream->SetCwd(cwd);
@@ -193,10 +193,16 @@ int LocalAccess::Do()
       done=true;
       return MOVED;
    case(RENAME):
+   case(LINK):
+   case(SYMLINK):
    {
       const char *cwd_file1=dir_file(cwd,file1);
-      cwd_file1=alloca_strdup(cwd_file1); // save it
-      if(rename(dir_file(cwd,file),cwd_file1)==-1)
+      int (*fn)(const char *f1,const char *f2)=(
+	 mode==RENAME ? rename :
+	 mode==LINK ? link :
+	 /*mode==SYMLINK?*/ symlink
+      );
+      if(fn(mode==SYMLINK?file.get():dir_file(cwd,file),cwd_file1)==-1)
       {
 	 errno_handle();
 	 error_code=NO_FILE;
@@ -338,14 +344,14 @@ read_again:
 
    if(res<0)
    {
-      if(E_RETRY(errno))
+      saved_errno=errno;
+      if(E_RETRY(saved_errno))
       {
 	 Block(stream->getfd(),POLLIN);
 	 return DO_AGAIN;
       }
-      if(stream->NonFatalError(errno))
+      if(stream->NonFatalError(saved_errno))
 	 return DO_AGAIN;
-      saved_errno=errno;
       return SEE_ERRNO;
    }
    stream->clear_status();
@@ -445,15 +451,16 @@ int LocalAccess::Write(const void *vbuf,int len)
    int res=write(fd,buf,len);
    if(res<0)
    {
-      if(E_RETRY(errno))
+      saved_errno=errno;
+      if(E_RETRY(saved_errno))
       {
 	 Block(stream->getfd(),POLLOUT);
 	 return DO_AGAIN;
       }
-      if(stream->NonFatalError(errno))
+      if(stream->NonFatalError(saved_errno))
       {
 	 // in case of full disk, check file correctness.
-	 if(errno==ENOSPC)
+	 if(saved_errno==ENOSPC)
 	 {
 	    struct stat st;
 	    if(fstat(fd,&st)!=-1)
@@ -468,7 +475,6 @@ int LocalAccess::Write(const void *vbuf,int len)
 	 }
 	 return DO_AGAIN;
       }
-      saved_errno=errno;
       return SEE_ERRNO;
    }
    stream->clear_status();
