@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: LocalAccess.h,v 1.15 2008/11/27 05:56:21 lav Exp $ */
+/* $Id: LocalAccess.h,v 1.16 2009/07/17 12:54:26 lav Exp $ */
 
 #ifndef LOCALACCESS_H
 #define LOCALACCESS_H
@@ -41,6 +40,7 @@ public:
    void Connect(const char *host,const char *port) {}
    void AnonymousLogin() {}
    void Login(const char *u,const char *p) {}
+   void ResetLocationData() {}
 
    const char *GetProto() const { return "file"; }
    FileAccess *Clone() const { return new LocalAccess(this); }
