@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-2010 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* $Id: MirrorJob.cc,v 1.178 2011/04/29 04:58:28 lav Exp $ */
@@ -1657,8 +1656,10 @@ CMD(mirror)
 	 {
 	    // user wants source dir name appended.
 	    const char *base=basename_ptr(source_dir);
-	    if(base[0]!='/' && strcmp(base,basename_ptr(arg)))
+	    if(base[0]!='/' && strcmp(base,basename_ptr(arg))) {
 	       target_dir=xstring::cat(target_dir,base,NULL);
+	       target_dir=alloca_strdup(target_dir); // save the buffer
+	    }
 	 }
       }
       else
@@ -1666,8 +1667,10 @@ CMD(mirror)
 	 target_dir=basename_ptr(source_dir);
 	 if(target_dir[0]=='/')
 	    target_dir=".";
-	 else if(target_dir[0]=='~')
-	    target_dir=alloca_strdup(dir_file(".",target_dir));
+	 else if(target_dir[0]=='~') {
+	    target_dir=dir_file(".",target_dir);
+	    target_dir=alloca_strdup(target_dir); // save the buffer
+	 }
       }
    }
 
