@@ -1,11 +1,11 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1999-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: NetAccess.h,v 1.49 2008/02/17 08:19:24 lav Exp $ */
+/* $Id: NetAccess.h,v 1.51 2009/07/17 13:03:01 lav Exp $ */
 
 #ifndef NETACCESS_H
 #define NETACCESS_H
@@ -28,7 +27,7 @@
 #include "LsCache.h"
 #include "RateLimit.h"
 
-class NetAccess : public FileAccess
+class NetAccess : public FileAccess, public Networker
 {
 protected:
    SMTaskRef<Resolver> resolver;
@@ -58,20 +57,12 @@ protected:
 
    int	 socket_buffer;
    int	 socket_maxseg;
-   void	 SetSocketBuffer(int sock);
-   void	 SetSocketMaxseg(int sock);
+   void	 SetSocketBuffer(int sock) { Networker::SetSocketBuffer(sock,socket_buffer); }
+   void	 SetSocketMaxseg(int sock) { Networker::SetSocketMaxseg(sock,socket_maxseg); }
+
+   int SocketCreate(int af,int type,int proto) { return Networker::SocketCreate(af,type,proto,hostname); }
+   int SocketCreateTCP(int af) { return Networker::SocketCreateTCP(af,hostname); }
 
-   static void KeepAlive(int sock);
-   static void MinimizeLatency(int sock);
-   static void MaximizeThroughput(int sock);
-   static void ReuseAddress(int sock);
-   static int SocketBuffered(int sock);
-   static const char *SocketNumericAddress(const sockaddr_u *u) { return u->address(); }
-   static int SocketPort(const sockaddr_u *u) { return u->port(); }
-   static socklen_t SocketAddrLen(const sockaddr_u *u) { return u->addr_len(); }
-   static int SocketConnect(int fd,const sockaddr_u *u);
-   int SocketCreate(int,int,int);
-   int SocketCreateTCP(int);
    int Poll(int fd,int ev);
    int CheckHangup(const struct pollfd *pfd,int num);
 
