@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 2002-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* Usage notes:
@@ -143,8 +142,7 @@ void OutputJob::InitCopy()
    if(!fail_if_broken)
       input_fc->DontFailIfBroken();
 
-   xstring_ca buf(xasprintf(_("%s (filter)"), a0.get()));
-   input=new CopyJob(input_fc, buf, filter?filter:a0);
+   input=new CopyJob(input_fc, xstring::format(_("%s (filter)"),a0.get()), filter?filter:a0);
 
    if(!output)
       output=input;
@@ -510,7 +508,7 @@ void OutputJob::Format(const char *f,...)
 {
    va_list v;
    va_start(v,f);
-   xstring_ca str(xvasprintf(f,v));
+   const xstring& str=xstring::vformat(f,v);
    va_end(v);
    Put(str);
 }
