@@ -1,11 +1,11 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 2001 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: PtyShell.h,v 1.3 2005/06/21 12:12:30 lav Exp $ */
+/* $Id: PtyShell.h,v 1.6 2008/11/27 05:56:25 lav Exp $ */
 
 #ifndef PTYSHELL_H
 #define PTYSHELL_H
@@ -27,11 +26,11 @@
 
 class PtyShell : public FDStream
 {
-   ArgV *a;
-   ProcWait *w;
+   Ref<ArgV> a;
+   Ref<ProcWait> w;
    pid_t pg;
 
-   char *oldcwd;
+   xstring_c oldcwd;
 
    bool closed;
    bool use_pipes;
