@@ -1,11 +1,11 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: ResMgr.h,v 1.52 2007/08/10 12:49:25 lav Exp $ */
+/* $Id: ResMgr.h,v 1.56 2011/02/10 13:28:56 lav Exp $ */
 
 #ifndef RESMGR_H
 #define RESMGR_H
@@ -45,6 +44,7 @@ struct ResType
 
    ResValue Query(const char *closure) const;
    bool QueryBool(const char *closure) const;
+   bool QueryTriBool(const char *closure,bool a) const;
 };
 
 class ResMgr
@@ -65,8 +65,8 @@ public:
 
       bool ClosureMatch(const char *cl_data);
 
-      Resource(Resource *next,const ResType *type,const char *closure,const char *value)
-	 : type(type), value(value), closure(closure), next(next) {}
+      Resource(Resource *next,const ResType *type,const char *closure,const char *value);
+      ~Resource();
    };
 
 private:
@@ -80,6 +80,7 @@ public:
    static const char *SimpleQuery(const char *name,const char *closure);
    static ResValue Query(const char *name,const char *closure);
    static bool QueryBool(const char *name,const char *closure);
+   static bool QueryTriBool(const char *name,const char *closure,bool a);
 
    enum CmpRes {
       EXACT_PREFIX=0x00,SUBSTR_PREFIX=0x01,
@@ -108,10 +109,11 @@ public:
    static const char *IPv6AddrValidate(xstring_c *value);
 #endif
    static const char *UNumberPairValidate(xstring_c *value);
-   static const char *FileAccessible(xstring_c *value,int mode,int want_dir=0);
+   static const char *FileAccessible(xstring_c *value,int mode,bool want_dir=false);
    static const char *FileReadable(xstring_c *value);
    static const char *FileExecutable(xstring_c *value);
    static const char *DirReadable(xstring_c *value);
+   static const char *FileCreatable(xstring_c *value);
    static const char *CharsetValidate(xstring_c *value);
    static const char *NoClosure(xstring_c *);
    static bool str2bool(const char *value);
@@ -143,50 +145,27 @@ public:
       {
 	 s=s_new;
       }
-   bool to_bool()
+   bool to_bool() const
       {
 	 return ResMgr::str2bool(s);
       }
-   operator int()
-      {
-	 return strtol(s,0,0);
-      }
-   operator long()
-      {
-	 return strtol(s,0,0);
-      }
-   operator double()
-      {
-	 return atof(s);
-      }
-   operator float()
-      {
-	 return atof(s);
-      }
-   operator const char*()
+   bool to_tri_bool(bool a) const;
+   unsigned long long to_unumber(unsigned long long max) const;
+   long long to_number(long long min,long long max) const;
+   operator int() const;
+   operator long() const;
+   operator unsigned() const;
+   operator unsigned long() const;
+   operator double() const { return atof(s); }
+   operator float() const  { return atof(s); }
+   operator const char*() const
       {
 	 return s;
       }
-   bool is_nil() { return s==0; }
-   void ToNumberPair(int &a,int &b)
-      {
-	 switch(sscanf(s,"%d%*c%d",&a,&b))
-	 {
-	 case 0: a=0;
-	 case 1: b=a;
-	 }
-      }
+   bool is_nil() const { return s==0; }
+   void ToNumberPair(int &a,int &b) const;
 };
 
-inline bool ResType::QueryBool(const char *closure) const
-{
-   return Query(closure).to_bool();
-}
-inline bool ResMgr::QueryBool(const char *name,const char *closure)
-{
-   return Query(name,closure).to_bool();
-}
-
 class TimeIntervalR : public TimeInterval
 {
    const char *error_text;
@@ -228,8 +207,8 @@ protected:
    virtual const char *ResClosure() const { return 0; }
    virtual void Reconfig(const char *) {}
    ResValue Query(const char *name,const char *closure=0) const;
-   bool QueryBool(const char *name,const char *closure=0) const
-      { return Query(name,closure).to_bool(); }
+   bool QueryBool(const char *name,const char *closure=0) const;
+   bool QueryTriBool(const char *name,const char *closure,bool a) const;
    ResClient();
    virtual ~ResClient();
 public:
