@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: Resolver.cc,v 1.85 2009/07/17 13:04:46 lav Exp $ */
+/* $Id: Resolver.cc,v 1.90 2011/03/25 14:35:43 lav Exp $ */
 
 #include <config.h>
 
@@ -45,6 +44,10 @@
 # include <resolv.h>
 #endif
 
+#ifdef DNSSEC_LOCAL_VALIDATION
+# include "validator/validator.h"
+#endif
+
 #include "xstring.h"
 #include "ResMgr.h"
 #include "log.h"
@@ -94,6 +97,7 @@ static const address_family af_list[]=
 
 ResolverCache *Resolver::cache;
 
+
 Resolver::Resolver(const char *h,const char *p,const char *defp,
 		   const char *ser,const char *pr)
    : hostname(h), portname(p), service(ser), proto(pr), defport(defp)
@@ -477,8 +481,8 @@ void Resolver::LookupSRV_RR()
    const char *tproto=proto?proto.get():"tcp";
    time_t try_time;
    unsigned char answer[0x1000];
-   char *srv_name=string_alloca(strlen(service)+1+strlen(tproto)+1+strlen(hostname)+1);
-   sprintf(srv_name,"_%s._%s.%s",service.get(),tproto,hostname.get());
+   const char *srv_name=xstring::format("_%s._%s.%s",service.get(),tproto,hostname.get());
+   srv_name=alloca_strdup(srv_name);
 
    int retries=0;
    int max_retries=ResMgr::Query("dns:max-retries",hostname);
@@ -492,9 +496,22 @@ void Resolver::LookupSRV_RR()
 	    return;
       }
       time(&try_time);
+
+#ifndef DNSSEC_LOCAL_VALIDATION
       len=res_search(srv_name, C_IN, T_SRV, answer, sizeof(answer));
       if(len>=0)
 	 break;
+#else
+      val_status_t val_status;
+      bool require_trust = ResMgr::QueryBool("dns:strict-dnssec",hostname);
+      len=val_res_search(NULL, srv_name, C_IN, T_SRV, answer, sizeof(answer), &val_status);
+      if(len>=0) {
+          if(require_trust && !val_istrusted(val_status))
+              return;
+          else
+              break;
+      }
+#endif
 #ifdef HAVE_H_ERRNO
       if(h_errno!=TRY_AGAIN)
 	 return;
@@ -702,7 +719,20 @@ void Resolver::LookupOne(const char *name)
       a_hint.ai_flags	    = AI_PASSIVE;
       a_hint.ai_family	    = PF_UNSPEC;
 
+#ifndef DNSSEC_LOCAL_VALIDATION
       ainfo_res	= getaddrinfo(name, NULL, &a_hint, &ainfo);
+#else
+      val_status_t val_status;
+      bool require_trust=ResMgr::QueryBool("dns:strict-dnssec",name);
+      ainfo_res	= val_getaddrinfo(NULL, name, NULL, &a_hint, &ainfo,
+                                  &val_status);
+      if(VAL_GETADDRINFO_HAS_STATUS(ainfo_res)
+      && !val_istrusted(val_status) && require_trust) {
+          // untrusted answer
+          error = _("DNS resoloution not trusted.");
+          break;
+      }
+#endif
 
       if(ainfo_res == 0)
       {
@@ -832,9 +862,7 @@ void Resolver::DoGethostbyname()
 	 else
 	 {
 	    buf->Put("P");
-	    char *msg=string_alloca(64+strlen(tproto));
-	    sprintf(msg,_("no such %s service"),tproto);
-	    buf->Put(msg);
+	    buf->Format(_("no such %s service"),tproto);
 	    goto flush;
 	 }
       }
