@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 2003-2008 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: SFtp.cc,v 1.86 2009/07/17 13:07:29 lav Exp $ */
+/* $Id: SFtp.cc,v 1.90 2011/03/25 14:35:43 lav Exp $ */
 
 #include <config.h>
 #include "SFtp.h"
@@ -636,6 +635,22 @@ void SFtp::SendRequest()
       SendRequest(new Request_REMOVE(WirePath(file)),Expect::DEFAULT);
       state=WAITING;
       break;
+   case LINK:
+      if(protocol_version<6) {
+	 SetError(NOT_SUPP);
+	 break;
+      }
+   case SYMLINK:
+      if(protocol_version<3) {
+	 SetError(NOT_SUPP);
+	 break;
+      }
+      if(protocol_version>=6)
+	 SendRequest(new Request_LINK(mode==SYMLINK?lc_to_utf8(file):WirePath(file),WirePath(file1),mode==SYMLINK),Expect::DEFAULT);
+      else
+	 SendRequest(new Request_SYMLINK(lc_to_utf8(file),WirePath(file1)),Expect::DEFAULT);
+      state=WAITING;
+      break;
    case QUOTE_CMD:
    case MP_LIST:
       SetError(NOT_SUPP);
@@ -1907,6 +1922,13 @@ void SFtp::Request_OPEN::Pack(Buffer *b)
    }
    attrs.Pack(b,protocol_version);
 }
+void SFtp::Request_RENAME::ComputeLength()
+{
+   Packet::ComputeLength();
+   length+=4+strlen(oldpath)+4+strlen(newpath);
+   if(protocol_version>=5)
+      length+=4; // flags
+}
 void SFtp::Request_RENAME::Pack(Buffer *b)
 {
    Packet::Pack(b);
@@ -1915,6 +1937,19 @@ void SFtp::Request_RENAME::Pack(Buffer *b)
    if(protocol_version>=5)
       PACK32(flags);
 }
+void SFtp::Request_SYMLINK::Pack(Buffer *b)
+{
+   Packet::Pack(b);
+   Packet::PackString(b,oldpath);
+   Packet::PackString(b,newpath);
+}
+void SFtp::Request_LINK::Pack(Buffer *b)
+{
+   Packet::Pack(b);
+   Packet::PackString(b,newpath);
+   Packet::PackString(b,oldpath);
+   PACK8(symbolic);
+}
 
 const char *SFtp::utf8_to_lc(const char *s)
 {
@@ -1978,10 +2013,10 @@ FileInfo *SFtp::MakeFileInfo(const NameAttrs *na)
       fi->SetSize(a->size);
    if(a->flags&SSH_FILEXFER_ATTR_UIDGID)
    {
-      char id[12];
-      sprintf(id,"%u",(unsigned)a->uid);
+      char id[24];
+      snprintf(id,sizeof(id),"%u",a->uid);
       fi->SetUser(id);
-      sprintf(id,"%u",(unsigned)a->gid);
+      snprintf(id,sizeof(id),"%u",a->gid);
       fi->SetGroup(id);
    }
    if(a->flags&SSH_FILEXFER_ATTR_OWNERGROUP)
