@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 2003-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: SFtp.h,v 1.29 2008/11/27 05:56:27 lav Exp $ */
+/* $Id: SFtp.h,v 1.32 2011/03/16 09:03:09 lav Exp $ */
 
 #ifndef SFTP_H
 #define SFTP_H
@@ -426,8 +425,8 @@ public:
       off_t    size;		    // present only if flag SIZE
       xstring  owner;		    // present only if flag OWNERGROUP // v>=4
       xstring  group;		    // present only if flag OWNERGROUP // v>=4
-      uid_t    uid;		    // present only if flag UIDGID // v<=3
-      gid_t    gid;		    // present only if flag UIDGID // v<=3
+      unsigned uid;		    // present only if flag UIDGID // v<=3
+      unsigned gid;		    // present only if flag UIDGID // v<=3
       unsigned permissions;	    // present only if flag PERMISSIONS
       time_t   atime;		    // present only if flag ACCESSTIME (ACMODTIME)
       unsigned atime_nseconds;	    // present only if flag SUBSECOND_TIMES
@@ -646,6 +645,16 @@ private:
 	    protocol_version=pv;
 	    flags=f;
 	 }
+      void ComputeLength();
+      void Pack(Buffer *b);
+   };
+   class Request_SYMLINK : public Packet
+   {
+      xstring oldpath;
+      xstring newpath;
+   public:
+      Request_SYMLINK(const char *o,const char *n)
+      : Packet(SSH_FXP_SYMLINK), oldpath(o), newpath(n) {}
       void ComputeLength()
 	 {
 	    Packet::ComputeLength();
@@ -653,6 +662,21 @@ private:
 	 }
       void Pack(Buffer *b);
    };
+   class Request_LINK : public Packet
+   {
+      xstring oldpath;
+      xstring newpath;
+      bool symbolic;
+   public:
+      Request_LINK(const char *o,const char *n,bool s)
+      : Packet(SSH_FXP_LINK), oldpath(o), newpath(n), symbolic(s) {}
+      void ComputeLength()
+	 {
+	    Packet::ComputeLength();
+	    length+=4+strlen(oldpath)+4+strlen(newpath)+1;
+	 }
+      void Pack(Buffer *b);
+   };
 
    struct Expect;
    friend struct SFtp::Expect; // grant access to Packet.
