@@ -1,11 +1,11 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-1997 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,30 +14,28 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: alias.h,v 1.1 1998/06/18 14:16:50 lav Exp $ */
+/* $Id: alias.h,v 1.5 2008/11/27 05:56:33 lav Exp $ */
 
 #ifndef ALIAS_H
 #define ALIAS_H
 
-#include "xmalloc.h"
+#include "xstring.h"
 
 class Alias
 {
    Alias *next;
-   char	 *alias;
-   char	 *value;
+   xstring_c alias;
+   xstring_c value;
 
    static Alias *base;
 
-   Alias(const char *alias,const char *value,Alias *next);
+   Alias(const char *alias,const char *value,Alias *next)
+      : next(next), alias(alias), value(value) {}
 
 public:
-   ~Alias();
-
    static const char *Find(const char *alias);
 
    static void Add(const char *alias,const char *value);
@@ -45,37 +43,26 @@ public:
 
    static char *Format();
 
-   friend char *command_generator(char *text,int state);
+   friend char *command_generator(const char *text,int state);
 };
 
 class TouchedAlias
 {
-   char *alias;
+   xstring_c alias;
    TouchedAlias *next;
 public:
    TouchedAlias(const char *a,TouchedAlias *n)
-   {
-      alias=xstrdup(a);
-      next=n;
-   }
-   ~TouchedAlias()
-   {
-      free(alias);
-   }
+      : alias(a), next(n) {}
    static void FreeChain(TouchedAlias *chain)
    {
       while(chain)
-      {
-	 TouchedAlias *next=chain->next;
-	 delete chain;
-	 chain=next;
-      }
+	 delete replace_value(chain,chain->next);
    }
    static bool IsTouched(const char *a,TouchedAlias *chain)
    {
       while(chain)
       {
-	 if(!strcmp(chain->alias,a))
+	 if(chain->alias.eq(a))
 	    return true;
 	 chain=chain->next;
       }
