@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1998-2008 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <config.h>
@@ -45,6 +44,8 @@ int IOBufferSSL::Do()
       {
 	 buffer_ptr+=res;
 	 event_time=now;
+	 if(eof)
+	    PutEOF_LL();
 	 return MOVED;
       }
       break;
@@ -114,7 +115,8 @@ int IOBufferSSL::Put_LL(const char *buf,int size)
 
 int IOBufferSSL::PutEOF_LL()
 {
-   ssl->shutdown();
+   if(Size()==0)
+      ssl->shutdown();
    return 0;
 }
 
