@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-2007 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: ftpclass.h,v 1.162 2010/03/05 10:44:12 lav Exp $ */
+/* $Id: ftpclass.h,v 1.166 2011/03/03 20:03:11 lav Exp $ */
 
 #ifndef FTPCLASS_H
 #define FTPCLASS_H
@@ -117,6 +116,7 @@ class Ftp : public NetAccess
       bool host_supported;
       bool mfmt_supported;
       bool epsv_supported;
+      bool tvfs_supported;
 
       off_t last_rest;	// last successful REST position.
       off_t rest_pos;	// the number sent with REST command.
@@ -163,6 +163,8 @@ class Ftp : public NetAccess
       void CloseAbortedDataConnection();
 
       void Send(const char *cmd);
+      void SendURI(const char *u,const char *home);
+      void SendCRNL();
       void SendEncoded(const char *url);
       void SendCmd(const char *cmd);
       void SendCmd2(const char *cmd,const char *f,const char *u=0,const char *home=0);
@@ -266,7 +268,7 @@ class Ftp : public NetAccess
    void	 proxy_NoPassReqCheck(int);
    void	 CheckFEAT(char *reply);
    char *ExtractPWD();
-   void  SendCWD(const char *path,Expect::expect_t c,const char *arg=0);
+   void  SendCWD(const char *path,const char *path_url,Expect::expect_t c);
    void	 CatchDATE(int);
    void	 CatchDATE_opt(int);
    void	 CatchSIZE(int);
@@ -368,6 +370,10 @@ private:
    bool force_skey;
    const char *make_skey_reply();
 
+   xstring netkey_pass;
+   bool allow_netkey;
+   const char *make_netkey_reply();
+
    bool disconnect_on_close;
 
 public:
