@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: history.cc,v 1.22 2008/11/27 05:56:37 lav Exp $ */
+/* $Id: history.cc,v 1.23 2011/03/25 14:35:43 lav Exp $ */
 
 #include <config.h>
 #include <sys/types.h>
@@ -138,16 +137,16 @@ void History::Set(const FileAccess *s,const FileAccess::Path &cwd)
 {
    if(cwd.path==0 || !strcmp(cwd.path,"~") || s->GetHostName()==0)
       return;
-   char *res=(char*)alloca(32+strlen(cwd.path)*3+xstrlen(cwd.url)+2);
-   sprintf(res,"%lu:",(unsigned long)time(0));
+   xstring res;
+   res.setf("%lu:",(unsigned long)time(0));
    if(!cwd.url)
    {
-      url::encode_string(cwd,res+strlen(res),URL_PATH_UNSAFE);
+      res.append_url_encoded(cwd,URL_PATH_UNSAFE);
       if(!cwd.is_file && url::dir_needs_trailing_slash(s->GetProto()))
-	 strcat(res,"/");
+	 res.append('/');
    }
    else
-      strcat(res,cwd.url);
+      res.append(cwd.url);
    super::Add(s->GetConnectURL(s->NO_PATH|s->NO_PASSWORD),res);
    modified=true;
 }
