@@ -1,11 +1,11 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-1998 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,16 +14,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: keyvalue.h,v 1.8 2002/07/10 07:58:23 lav Exp $ */
+/* $Id: keyvalue.h,v 1.12 2008/11/27 05:56:38 lav Exp $ */
 
 #ifndef KEYVALUE_H
 #define KEYVALUE_H
 
-#include "xmalloc.h"
+#include "xstring.h"
 
 class StringMangler
 {
@@ -36,35 +35,24 @@ public:
 
 class KeyValueDB
 {
-protected:
+public:
    class Pair
    {
    public:
-      char *key;
-      char *value;
+      xstring_c key;
+      xstring_c value;
       Pair *next;
       Pair(const char *k,const char *v)
-	 {
-	    key=xstrdup(k);
-	    value=xstrdup(v);
-	    next=0;
-	 }
-      virtual ~Pair()
-	 {
-	    xfree(key);
-	    xfree(value);
-	 }
+	 : key(k), value(v), next(0) {}
+      virtual ~Pair() {}
       int KeyCompare(const char *s) const
 	 {
 	    return strcmp(s,key);
 	 }
-      void SetValue(const char *v)
-	 {
-	    xfree(value);
-	    value=xstrdup(v);
-	 }
+      void SetValue(const char *v) { value.set(v); }
    };
 
+protected:
    void Purge(Pair **p)
       {
 	 Pair *to_free=*p;
