@@ -1,7 +1,7 @@
 /*
  * lftp - file transfer program
  *
- * Copyright (c) 1999-2001 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: lftp_rl.c,v 1.19 2009/11/17 08:18:37 lav Exp $ */
+/* $Id: lftp_rl.c,v 1.20 2010/11/24 07:46:45 lav Exp $ */
 
 #include <config.h>
 #include <stdio.h>
@@ -157,11 +156,11 @@ void lftp_rl_init(
    rl_attempted_completion_function  =attempted_completion_function;
    rl_getc_function                  =getc_function;
    rl_completer_quote_characters     =completer_quote_characters;
-   rl_completer_word_break_characters=completer_word_break_characters;
+   rl_completer_word_break_characters=(char*)completer_word_break_characters;
    rl_filename_quote_characters      =filename_quote_characters;
    rl_filename_quoting_function      =filename_quoting_function;
-   rl_filename_dequoting_function    =filename_dequoting_function;
-   rl_char_is_quoted_p               =char_is_quoted_p;
+   rl_filename_dequoting_function    =(rl_dequote_func_t*)filename_dequoting_function;
+   rl_char_is_quoted_p               =(rl_linebuf_func_t*)char_is_quoted_p;
 
    rl_completion_display_matches_hook = lftp_rl_display_match_list;
 }
