@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1998-2001 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: log.cc,v 1.23 2008/11/27 05:56:40 lav Exp $ */
+/* $Id: log.cc,v 1.24 2009/03/20 12:26:48 lav Exp $ */
 
 #include <config.h>
 
@@ -133,3 +132,12 @@ Log::~Log()
 {
    CloseOutput();
 }
+
+void Log::SetOutput(int o,bool need_close)
+{
+   CloseOutput();
+   output=o;
+   need_close_output=need_close;
+   if(output!=-1)
+      tty=isatty(output);
+}
