@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-2007 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: mgetJob.cc,v 1.29 2009/04/27 07:54:59 lav Exp $ */
+/* $Id: mgetJob.cc,v 1.33 2011/04/29 04:58:29 lav Exp $ */
 
 #include <config.h>
 #include <sys/types.h>
@@ -42,23 +41,19 @@ void mgetJob::ShowRunStatus(const SMTaskRef<StatusLine>& s)
    }
    GetJob::ShowRunStatus(s);
 }
-void mgetJob::PrintStatus(int v,const char *prefix)
+xstring& mgetJob::FormatStatus(xstring& buf,int v,const char *prefix)
 {
    if(mkdir_job)
-   {
-      printf("\tCreating remote directories\n");
-      return;
-   }
+      return buf.append("\tCreating remote directories\n");
    if(rg)
    {
-      SessionJob::PrintStatus(v,prefix);
+      SessionJob::FormatStatus(buf,v,prefix);
       const char *s=rg->Status();
       if(!s || !s[0])
-	 return;
-      printf("\t%s\n",s);
-      return;
+	 return buf;
+      return buf.appendf("\t%s\n",s);
    }
-   GetJob::PrintStatus(v,prefix);
+   return GetJob::FormatStatus(buf,v,prefix);
 }
 
 mgetJob::mgetJob(FileAccess *session,ArgV *a,bool c,bool md)
@@ -122,8 +117,10 @@ void mgetJob::LocalGlob(const char *p)
    glob(p,0,0,&pglob);
    if(pglob.gl_pathc==0)
    {
-      fprintf(stderr,_("%s: no files found\n"),p);
-      return;
+      fprintf(stderr,_("%s: %s: no files found\n"),op,p);
+      count++;
+      errors++;
+      goto leave;
    }
    for(i=0; i<(int)pglob.gl_pathc; i++)
    {
@@ -137,6 +134,7 @@ void mgetJob::LocalGlob(const char *p)
       make_directory(src);
       args->Append(output_file_name(src,0,!reverse,output_dir,make_dirs));
    }
+leave:
    globfree(&pglob);
 }
 
@@ -189,7 +187,9 @@ int mgetJob::Do()
 
    if(rg->Error())
    {
-      fprintf(stderr,"rglob: %s\n",rg->ErrorText());
+      fprintf(stderr,"%s: %s: %s\n",op,rg->GetPattern(),rg->ErrorText());
+      count++;
+      errors++;
       goto next;
    }
 
@@ -201,7 +201,9 @@ int mgetJob::Do()
    FileSet *files=rg->GetResult();
    if(files->get_fnum()==0)
    {
-      fprintf(stderr,_("%s: no files found\n"),rg->GetPattern());
+      fprintf(stderr,_("%s: %s: no files found\n"),op,rg->GetPattern());
+      count++;
+      errors++;
       goto next;
    }
    do {
