@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-2005 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: misc.cc,v 1.98 2009/12/18 17:00:42 lav Exp $ */
+/* $Id: misc.cc,v 1.102 2011/03/25 14:35:43 lav Exp $ */
 
 #include <config.h>
 #include "xmalloc.h"
@@ -502,7 +501,7 @@ static void set_tz(const char *tz)
    char *new_tz=put_tz;
    if(tz_len>put_tz_alloc)
       new_tz=(char*)xmalloc(put_tz_alloc=tz_len);
-   sprintf(new_tz,"TZ=%s",tz);
+   snprintf(new_tz,tz_len,"TZ=%s",tz);
    if(new_tz!=put_tz)
    {
       putenv(new_tz);
@@ -529,8 +528,9 @@ time_t mktime_from_tz(struct tm *t,const char *tz)
       return mktime_from_utc(t);
    if(isdigit((unsigned char)*tz) || *tz=='+' || *tz=='-')
    {
-      char *tz1=string_alloca(strlen(tz)+4);
-      sprintf(tz1,"GMT%s",tz);
+      int tz1_len=strlen(tz)+4;
+      char *tz1=string_alloca(tz1_len);
+      snprintf(tz1,tz1_len,"GMT%s",tz);
       tz=tz1;
    }
    save_tz();
@@ -651,19 +651,6 @@ char *xstrftime(const char *format, const struct tm *tm)
    }
 }
 
-char *xvasprintf(const char *format, va_list ap)
-{
-   return xstring::vformat(format,ap).borrow();
-}
-char *xasprintf(const char *format, ...)
-{
-   va_list va;
-   va_start(va, format);
-   char *str=xvasprintf(format,va);
-   va_end(va);
-   return str;
-}
-
 /* /file/name -> /file
  * /file -> /
  * file/name -> "file"
@@ -794,11 +781,7 @@ const char *get_lftp_home()
    {
       home=getenv("HOME");
       if(home)
-      {
-         char *tmp=(char*)malloc(strlen(home)+6+1);
-         sprintf(tmp,"%s/.lftp",home);
-         home=tmp;
-      }
+         home=xstring::cat(home,"/.lftp",NULL).borrow();
       else
          return NULL;
    }
@@ -867,6 +850,7 @@ const char *shell_encode(const char *string)
 
 void remove_tags(char *buf)
 {
+   int len=strlen(buf);
    for(;;)
    {
       char *less=strchr(buf,'<');
@@ -876,17 +860,25 @@ void remove_tags(char *buf)
       if(amp && (!less || amp<less))
       {
 	 amp[0]=' ';
-	 memmove(amp+1,amp+6,strlen(amp+6)+1);
+	 memmove(amp+1,amp+6,len-(amp+6-buf)+1);
+	 len-=amp+6-buf;
 	 buf=amp+1;
 	 continue;
       }
       char *more=strchr(less+1,'>');
       if(!more)
 	 break;
-      memmove(less,more+1,strlen(more+1)+1);
+      memmove(less,more+1,len-(more+1-buf)+1);
+      len-=more+1-buf;
       buf=less;
    }
 }
+void rtrim(char *s)
+{
+   int len=strlen(s);
+   while(len>0 && (s[len-1]==' ' || s[len-1]=='\t' || s[len-1]=='\r'))
+      s[--len]=0;
+}
 
 bool in_foreground_pgrp()
 {
@@ -904,3 +896,17 @@ bool in_foreground_pgrp()
       return true;
    return false;
 }
+
+void random_init()
+{
+   static bool init;
+   if(!init)
+   {
+      srandom(time(NULL)+getpid());
+      init=true;
+   }
+}
+double random01()
+{
+   return random()/2147483648.0;
+}
