@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1999-2008 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: resource.cc,v 1.164 2010/03/18 08:09:38 lav Exp $ */
+/* $Id: resource.cc,v 1.171 2011/04/22 15:43:11 lav Exp $ */
 
 #include <config.h>
 
@@ -200,6 +199,7 @@ static ResType lftp_vars[] = {
    {"ftp:timezone",		 "GMT",   0,0},
    {"ftp:skey-allow",		 "yes",   ResMgr::BoolValidate,0},
    {"ftp:skey-force",		 "no",    ResMgr::BoolValidate,0},
+   {"ftp:netkey-allow",		 "yes",   ResMgr::BoolValidate,0},
 #if USE_SSL
    {"ftp:ssl-allow",		 "yes",   ResMgr::BoolValidate,0},
    {"ftp:ssl-force",		 "no",	  ResMgr::BoolValidate,0},
@@ -234,6 +234,8 @@ static ResType lftp_vars[] = {
    {"ftp:use-stat",		 "yes",   ResMgr::BoolValidate,0},
    {"ftp:use-stat-for-list",	 "no",	  ResMgr::BoolValidate,0},
    {"ftp:use-telnet-iac",	 "yes",   ResMgr::BoolValidate,0},
+   {"ftp:use-tvfs",		 "auto",  ResMgr::TriBoolValidate,0},
+   {"ftp:use-ip-tos",		 "no",	  ResMgr::BoolValidate,0},
    {"ftp:use-quit",		 "yes",   ResMgr::BoolValidate,0},
    {"ftp:verify-address",	 "no",    ResMgr::BoolValidate,0},
    {"ftp:verify-port",		 "no",    ResMgr::BoolValidate,0},
@@ -301,9 +303,10 @@ static ResType lftp_vars[] = {
    {"mirror:set-permissions",	 "yes",   ResMgr::BoolValidate,ResMgr::NoClosure},
    {"mirror:dereference",	 "no",    ResMgr::BoolValidate,ResMgr::NoClosure},
    {"mirror:skip-noaccess",	 "no",    ResMgr::BoolValidate,ResMgr::NoClosure},
+   {"mirror:no-empty-dirs",	 "no",	  ResMgr::BoolValidate,ResMgr::NoClosure},
 
    {"sftp:max-packets-in-flight","16",	  ResMgr::UNumberValidate,0},
-   {"sftp:protocol-version",	 "4",	  ResMgr::UNumberValidate,0},
+   {"sftp:protocol-version",	 "6",	  ResMgr::UNumberValidate,0},
    {"sftp:size-read",		 "32k",	  ResMgr::UNumberValidate,0},
    {"sftp:size-write",		 "32k",	  ResMgr::UNumberValidate,0},
    {"sftp:connect-program",	 "ssh -a -x",0,0},
@@ -341,6 +344,7 @@ static ResType lftp_vars[] = {
    {"xfer:verify-command",	 "",	  ResMgr::FileExecutable,0},
    {"xfer:log",			 "yes",	  ResMgr::BoolValidate,ResMgr::NoClosure},
    {"xfer:auto-rename",		 "no",	  ResMgr::BoolValidate,ResMgr::NoClosure},
+   {"xfer:log-file",              "",     ResMgr::FileCreatable,ResMgr::NoClosure},
 
 #if USE_SSL
    {"ssl:ca-file",		 "",	  ResMgr::FileReadable,ResMgr::NoClosure},
@@ -348,7 +352,7 @@ static ResType lftp_vars[] = {
    {"ssl:key-file",		 "",	  ResMgr::FileReadable,0},
    {"ssl:cert-file",		 "",	  ResMgr::FileReadable,0},
    {"ssl:check-hostname",	 "yes",	  ResMgr::BoolValidate,0},
-   {"ssl:verify-certificate",	 "no",	  ResMgr::BoolValidate,0},
+   {"ssl:verify-certificate",	 "yes",	  ResMgr::BoolValidate,0},
 # if USE_OPENSSL
    {"ssl:ca-path",		 "",	  ResMgr::DirReadable,ResMgr::NoClosure},
    {"ssl:crl-path",		 "",	  ResMgr::DirReadable,ResMgr::NoClosure},
