@@ -1,11 +1,11 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-1997 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef RMJOB_H
@@ -25,24 +24,19 @@
 
 class rmJob : public TreatFileJob
 {
-   void TreatCurrent();
+   void TreatCurrent(const char *, const FileInfo *);
 
 protected:
    FA::open_mode mode;
 
+   bool recurse;
+
 public:
-   void	 SayFinal();
+   void	SayFinal();
+   void Recurse(); // rm -r
+   void Rmdir() { mode=FA::REMOVE_DIR; }
 
    rmJob(FileAccess *session,ArgV *a);
 };
 
-class rmdirJob : public rmJob
-{
-public:
-   rmdirJob(FileAccess *session,ArgV *a) : rmJob(session,a)
-   {
-      mode=FA::REMOVE_DIR;
-   }
-};
-
 #endif // RMJOB_H
