@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 1996-2008 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef URL_H
@@ -67,13 +66,10 @@ public:
    char *Combine();
 
    // encode unsafe chars as %XY
-   static char *encode_string(const char *,char *buf=0,const char *u=URL_UNSAFE);
    static xstring& encode(const char *s,int len,const char *unsafe);
    static xstring& encode(const xstring &s,const char *unsafe) { return encode(s,s.length(),unsafe); }
    static xstring& encode(const char *s,const char *unsafe) { return encode(s,strlen(s),unsafe); }
-   // reverse; done in-place; returns length.
-   static int decode_string(char *);
-   static xstring& decode(const char *);
+   static xstring& decode(const char *) __attribute__((warn_unused_result));
 
    static bool is_url(const char *p);
    static int path_index(const char *p);
