@@ -1,7 +1,7 @@
 /*
- * lftp and utils
+ * lftp - file transfer program
  *
- * Copyright (c) 2007 by Alexander V. Lukyanov (lav@yars.free.net)
+ * Copyright (c) 1996-2011 by Alexander V. Lukyanov (lav@yars.free.net)
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,11 +14,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-/* $Id: xarray.h,v 1.9 2008/11/27 05:56:45 lav Exp $ */
+/* $Id: xarray.h,v 1.12 2009/08/14 13:13:25 lav Exp $ */
 
 #ifndef XARRAY_H
 #define XARRAY_H 1
@@ -75,6 +74,8 @@ public:
       if(len>0)
 	 ::qsort(buf,len,element_size,cmp);
    }
+   bool _bsearch(const void*,qsort_cmp_t,int *);
+   void *_insert_ordered(const void*,qsort_cmp_t);
 };
 
 template<typename T>
@@ -102,9 +103,13 @@ public:
    void chop() { _chop(); }
    T& last() { return (*this)[len-1]; }
    T *borrow() { return static_cast<T*>(_borrow()); }
-   void qsort(int (*cmp)(const T*,const T*)) {
+   typedef int (*cmp_t)(const T*,const T*);
+   void qsort(cmp_t cmp) {
       xarray0::qsort((qsort_cmp_t)cmp);
    }
+   void insert_ordered(const T& n,cmp_t cmp) {
+      *static_cast<T*>(_insert_ordered(&n,(qsort_cmp_t)cmp))=n;
+   }
    int search(const T &x) const {
       for(int i=0; i<len; i++)
       {
@@ -113,6 +118,18 @@ public:
       }
       return -1;
    }
+   bool bsearch(const T &x,cmp_t cmp,int *pos) {
+      return _bsearch(&x,(qsort_cmp_t)cmp,pos);
+   }
+   int bsearch(const T &x,cmp_t cmp) {
+      int pos;
+      return bsearch(x,cmp,&pos) ? pos : -1;
+   }
+   void allocate(int c,const T& fill) {
+      while(c-->0) {
+	 append(fill);
+      }
+   }
 };
 
 template<typename T,typename RefT>
@@ -140,6 +157,11 @@ public:
    void chop() { dispose(len-1); _chop(); }
    RefT& last() { return (*this)[len-1]; }
    RefT *borrow() { return static_cast<RefT*>(_borrow()); }
+   void allocate(int c) { while(c-->0) append((T*)0); }
+   typedef int (*cmp_t)(const RefT*,const RefT*);
+   void qsort(cmp_t cmp) {
+      xarray0::qsort((qsort_cmp_t)cmp);
+   }
 };
 
 template<typename T>
@@ -192,25 +214,42 @@ public:
 };
 
 
-template<typename T,class A> class xqueue
+
+template<typename T,class A,typename P> class _xqueue
 {
+protected:
    A q;
    int ptr;
 public:
-   xqueue() : ptr(0) {}
-   int count() { return q.count()-ptr; }
+   _xqueue() : ptr(0) {}
+   int count() const { return q.count()-ptr; }
    void empty() { q.truncate(); ptr=0; }
-   void push(const T &n) {
+   void push(P n) {
       if(ptr>count()) {
 	 q.remove(0,ptr);
 	 ptr=0;
       }
       q.append(n);
    }
+   void remove(int i) {
+      if(i==0)
+	 ptr++;
+      else
+	 q.remove(ptr+i);
+   }
    // returned pointer valid till the next push
    T& next() { return q[ptr++]; }
    T& operator[](int i) { return q[ptr+i]; }
-   void move_here(xqueue& o) { q.move_here(o.q); ptr=o.ptr; o.ptr=0; }
+   const T& operator[](int i) const { return q[ptr+i]; }
+   void move_here(_xqueue& o) { q.move_here(o.q); ptr=o.ptr; o.ptr=0; }
+};
+
+template<typename T,class A> class xqueue : public _xqueue<T,A,const T&>
+{
+};
+
+template<typename T> class RefQueue : public _xqueue<Ref<T>,RefArray<T>,T*>
+{
 };
 
 #endif // XARRAY_H
